.. qnum::
   :prefix: 11-2-
   :start: 2


Post Test and Survey
:::::::::::::::::::::::

Please complete the survey questions and click on the Post-test link below.

.. toctree::
   :maxdepth: 3

   posttest.rst



Post-Survey
============

.. poll:: qprogrammingpost
   :option_1: beginner programmer
   :option_2: intermediate programmer
   :option_3: expert programmer
   :option_4: prefer not to answer

   I am now a :

.. poll:: qconfidencepost
   :option_1: strongly agree
   :option_2: agree
   :option_3: neither agree or disagree
   :option_4: disagree
   :option_5: strongly disagree
   :option_6: prefer not to answer

   I am confident in my Java programming skills.

.. poll:: qenjoypost
   :option_1: strongly agree
   :option_2: agree
   :option_3: neither agree or disagree
   :option_4: disagree
   :option_5: strongly disagree
   :option_6: prefer not to answer

   I enjoyed learning about computer science and Java in this course.


.. poll:: qcareerpost
   :option_1: strongly agree
   :option_2: agree
   :option_3: neither agree or disagree
   :option_4: disagree
   :option_5: strongly disagree
   :option_6: prefer not to answer

   I would like to pursue further study or a career in computing.

.. shortanswer:: qbest

    What did you like best about this course?

.. shortanswer:: qimprove

    How could this course be improved?
